Special Thanks
==============
This project uses code from the following project:

* `rkern/line_profiler <https://github.com/rkern/line_profiler>`_

This project is inspired by the following project:

* `kainosnoema/rack-lineprof <https://github.com/kainosnoema/rack-lineprof>`_

wsgi_lineprof is integrated with the following projects:

* `kobinpy/wsgicli <https://github.com/kobinpy/wsgicli>`_
* `denzow/wsgi_lineprof_reporter <https://github.com/denzow/wsgi_lineprof_reporter>`_

wsgi_lineprof is mentioned in the following entries:

* `1日目 Peter Wang氏キーノート，変数アノテーション，自然言語処理，PythonでWebセキュリティ自動化～新企画「メディア会議」に注目：PyCon JP 2017カンファレンスレポート｜gihyo.jp … 技術評論社 <http://gihyo.jp/news/report/01/pyconjp2017/0001?page=4>`_
* `DjangoにDjangoミドルウェアとWSGIミドルウェアを組み込んでみた - メモ的な思考的な <http://thinkami.hatenablog.com/entry/2016/12/13/061856>`_
* `PythonのWSGIラインプロファイラを試してみた(wsgi_lineprof) - [Dd]enzow(ill)? with DB and Python <http://www.denzow.me/entry/2017/09/18/162154>`_
* `PythonのWSGIラインプロファイラの結果を使いやすくしてみた(wsgi_lineprof_reporter) - [Dd]enzow(ill)? with DB and Python <http://www.denzow.me/entry/2017/09/20/233219>`_
* `Server-side development — c2cgeoportal documentation <https://camptocamp.github.io/c2cgeoportal/master/developer/server_side.html>`_
